package model

import (
	operationPb "kpt-tmr-group/proto/go/backend/operation"
	"time"
)

type SystemMenu struct {
	Id        int64                   `json:"id,omitempty"`
	Name      string                  `json:"name,omitempty"`
	MenuType  int32                   `json:"menu_type,omitempty"`
	Level     int32                   `json:"level,omitempty"`
	Title     string                  `json:"title,omitempty"`
	Path      string                  `json:"path,omitempty"`
	IsShow    operationPb.IsShow_Kind `json:"is_show,omitempty"`
	IsDelete  operationPb.IsShow_Kind `json:"is_delete,omitempty"`
	Component string                  `json:"component,omitempty"`
	Icon      string                  `json:"icon,omitempty"`
	Sort      int32                   `json:"sort,omitempty"`
	ParentId  int64                   `json:"parent_id"`
	Redirect  string                  `json:"redirect,omitempty"`
	CreatedAt int64                   `json:"created_at,omitempty"`
	UpdatedAt int64                   `json:"updated_at,omitempty"`
}

func (s *SystemMenu) TableName() string {
	return "system_menu"
}

func NewSystemMenu(req *operationPb.AddMenuRequest) *SystemMenu {
	return &SystemMenu{
		Name:      req.Name,
		MenuType:  req.MenuType,
		Title:     req.Title,
		Path:      req.Path,
		Component: req.Component,
		Icon:      req.Icon,
		Sort:      req.Sort,
		Redirect:  req.Redirect,
		ParentId:  req.ParentId,
		IsShow:    operationPb.IsShow_OK,
		IsDelete:  operationPb.IsShow_OK,
	}
}

type SystemMenuSlice []*SystemMenu

func (s SystemMenuSlice) ToPB() []*operationPb.AddMenuRequest {
	res := make([]*operationPb.AddMenuRequest, len(s))
	for i, v := range s {
		res[i] = &operationPb.AddMenuRequest{
			Id:              v.Id,
			Name:            v.Name,
			MenuType:        v.MenuType,
			Level:           v.Level,
			Title:           v.Title,
			IsShow:          v.IsShow,
			Component:       v.Component,
			Icon:            v.Icon,
			Sort:            v.Sort,
			Redirect:        v.Redirect,
			ParentId:        v.ParentId,
			CreatedAt:       v.CreatedAt,
			CreatedAtFormat: time.Unix(v.CreatedAt, 0).Format(LayoutTime),
		}
	}
	return res
}

func (s *SystemMenu) ToPb() *operationPb.AddMenuRequest {
	return &operationPb.AddMenuRequest{
		Id:        s.Id,
		Name:      s.Name,
		MenuType:  s.MenuType,
		Level:     s.Level,
		Title:     s.Title,
		Path:      s.Path,
		Component: s.Component,
		Icon:      s.Icon,
		Sort:      s.Sort,
		Redirect:  s.Redirect,
		ParentId:  s.ParentId,
		IsShow:    s.IsShow,
		CreatedAt: s.CreatedAt,
	}
}

type SystemMenuResponse struct {
	Page  int32                         `json:"page"`
	Total int32                         `json:"total"`
	List  []*operationPb.AddMenuRequest `json:"list"`
}

func (s *SystemMenuResponse) ToPB() *operationPb.SearchMenuResponse {
	return &operationPb.SearchMenuResponse{
		Page:  s.Page,
		Total: s.Total,
		List:  s.List,
	}
}
